alandipert.desiderata.invoke


deftypefncljmacro

(deftypefn name [& fields] f & opts+specs)

Like deftype, but accepts a function f before any specs. f should accept at least one argument, 'this'.

Like deftype, but accepts a function f before any specs.  f should
accept at least one argument, 'this'.
sourceraw docstring

extend-IFnclj

(extend-IFn f)
source

gen-apply-toclj

(gen-apply-to f)
source

gen-nonvariadic-invokesclj

(gen-nonvariadic-invokes f)
source

gen-variadic-invokeclj

(gen-variadic-invoke f)
source

reifncljmacro

(reifn f & opts+specs)

Like reify, but accepts a function f as a first argument that is used to implement clojure.lang.IFn. f should accept at least one argument, 'this'.

Like reify, but accepts a function f as a first argument that is
used to implement clojure.lang.IFn. f should accept at least one
argument, 'this'.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries