(deftypefn name [& fields] f & opts+specs)Like deftype, but accepts a function f before any specs. f should accept at least one argument, 'this'.
Like deftype, but accepts a function f before any specs. f should accept at least one argument, 'this'.
(reifn f & opts+specs)Like reify, but accepts a function f as a first argument that is used to implement clojure.lang.IFn. f should accept at least one argument, 'this'.
Like reify, but accepts a function f as a first argument that is used to implement clojure.lang.IFn. f should accept at least one argument, 'this'.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |